Learn R Programming

Bayesthresh (version 2.0.1)

sensory: Sensory analysis of banana

Description

An data set for illustrated of the use package Bayesthresh

Usage

data(sensory) sensory

Arguments

Details

Data used by Silva and Bueno-Filho (2010) for illustrated the using of the algorithm ACG and ACt.

References

SILVA, W.J,; BUENO FILHO. (2010) An algorithm for thresholds models using cumulative Gaussian or cummulative Student's "t" distributions. Brazilian Journal of Biometry, Sao Paulo, v. 28, n. 3, p.59-83.